Tutorials
=========

First steps with Python, LilyPond and Abjad
-------------------------------------------

..  container:: two-column

    ..  toctree::
        :numbered:

        getting_started/index
        lilypond_hello_world/index
        python_hello_world_at_the_interpreter/index
        python_hello_world_in_a_file/index
        more_about_python/index
        abjad_hello_world_at_the_interpreter/index
        abjad_hello_world_in_a_file/index
        more_about_abjad/index

Working with notation
---------------------

..  container:: two-column

    ..  toctree::
        :numbered:

        working_with_lists_of_numbers/index
        changing_notes_to_rests/index
        creating_rest_delimited_slurs/index
        mapping_lists_to_rhythms/index
        overriding_lilypond_grobs/index
        working_with_component_parentage/index
        working_with_logical_voices/index
